<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>ಸಹಕರಣ</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>ಸಹಕರಣ ಒಂದು ಶಕ್ತಿಶಾಲಿಯಾದ ಕ್ರಾಸ್-ಟರ್ಮಿನಲ್ ಕಛೇರಿ ಸಾಧನವಾಗಿದೆ, ಇದು ನೀವು ಅನೇಕ ಸಾಧನಗಳ ನಡುವೆ ಅಂತರ್ಗತ ದೋಸ್ತುಗಳನ್ನು ಹಂಚಿಕೊಳ್ಳುವುದನ್ನು, ಕೀಗಳನ್ನು ಹಂಚಿಕೊಳ್ಳುವುದನ್ನು ಮತ್ತು ಕ್ಲಿಪ್ಬ್ಯಾರ್ಡ್ ಗಳನ್ನು ಹಂಚಿಕೊಳ್ಳುವುದನ್ನು ಸಹಾಯ ಮಾಡುತ್ತದೆ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>ಪತ್ರ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ ಆಯ್ಕೆಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>ಆಯ್ಕೆಗಳು</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>ಖಾಸ್ಯ ಐಪಿ: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; ನಿಮ್ಮಿಗೆ ಕೆಲವು ಪತ್ರಗಳನ್ನು ಕಳುಹಿಸುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>ಅಸ್ಪೃಹಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>ಪ್ರಮಾಣೀಕರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>ಹುಡುಕಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>ರದ್ದುಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>ಅಸ್ಪೃಹಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>ಪ್ರಮಾಣೀಕರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>ಮುಚ್ಚಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>ಪತ್ರ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>ಪತ್ರ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>ಹೆಲ್ಪ್ ಮಾನುಷಲ್ ನೋಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>dde-cooperation ಗೆ ಸ್ವಾಗತ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>ಕೀಬೋರ್ಡ್ ಮತ್ತು ಮೌಸ್ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>ಎರಡು ಸಾಧನಗಳ ನಡುವೆ ಸಂಪರ್ಕ ಸೃಷ್ಟಿಸಿದ ನಂತರ, ಪ್ರಾರಂಭಕನ ಕೀಬೋರ್ಡ್ ಮತ್ತು ಮೌಸ್ ಅನ್ನು ಇನ್ನೊಂದು ಸಾಧನವನ್ನು ನಿಯಂತ್ರಿಸಲು ಬಳಸಬಹುದು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>ಕ್ಲಿಪ್ಬ್ಯಾರ್ಡ್ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>ಎರಡು ಸಾಧನಗಳ ನಡುವೆ ಸಂಪರ್ಕ ಸೃಷ್ಟಿಸಿದ ನಂತರ, ಕ್ಲಿಪ್ಬ್ಯಾರ್ಡ್ ಹಂಚಿಕೊಳ್ಳಲು ಸಾಧ್ಯವಾಗುತ್ತದೆ ಮತ್ತು ಒಂದು ಸಾಧನದಲ್ಲಿ ಕಾಪಿಯಾಗಿಸಿದ ನಂತರ ಇನ್ನೊಂದು ಸಾಧನದಲ್ಲಿ ಅದನ್ನು ಅನುಕರಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>ದಾಸ್ತಾನುಗಳ ಹಂಚಿಕೊಳ್ಳುವಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>ಎರಡು ಸಾಧನಗಳ ನಡುವೆ ಸಂಪರ್ಕ ಸೃಷ್ಟಿಸಿದ ನಂತರ, ನೀವು ಇನ್ನೊಂದು ಸಾಧನಕ್ಕೆ ಪತ್ರ ಹಂಚಿಕೊಳ್ಳುವಿಕೆಯನ್ನು ಪ್ರಾರಂಭಿಸಬಹುದು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>ವಿವರವಾದ ಸೂಚನೆಗಳಿಗಾಗಿ, ಕೆಳಗಿನ ಹೆಲ್ಪ್ ಮಾನುಷಲ್ ಗೆ ಕ್ಲಿಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>ಉಪಯೋಗ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>ಸಂಪರ್ಕದಲ್ಲಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>ಸಂಪರ್ಕಕ್ಕೆ ಅನುಮತಿಸುವ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>ಆಫ್ಲೈನ್</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>ನಿರ್ಧರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>ಮುಚ್ಚು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>ಲ್ಯಾಂ ಡಿಸ್ಕವರಿ ಸೇವೆಯನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಲು ದಯವಿಟ್ಟು ಅನುಮತಿಸಲು ಕ್ಲಿಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>ಲ್ಯಾಂ ಡಿಸ್ಕವರಿ ಸೇವೆಯನ್ನು ಸಕ್ರಿಯಗೊಳಿಸದಿದ್ದರೆ, ಇತರ ಉಪಕರಣಗಳಿಂದ ಡಿಸ್ಕವರಿ ಮಾಡಲು ಮತ್ತು ಡಿಸ್ಕವರಿಯಾಗಲು ಸಾಧ್ಯವಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>ಲ್ಯಾಂ ಡಿಸ್ಕವರಿ ಸೇವೆಯನ್ನು ಸಕ್ರಿಯಗೊಳಿಸದಿದ್ದರೆ, ಇತರ ಉಪಕರಣಗಳಿಂದ ಡಿಸ್ಕವರಿ ಮಾಡಲು ಮತ್ತು ಡಿಸ್ಕವರಿಯಾಗಲು ಸಾಧ್ಯವಿಲ್ಲ. Windows Start menu ಗೆ ಬಲ ಕ್ಲಿಕ್ ಮಾಡಿ -&gt; Computer Management -&gt; Services and Applications -&gt; Services ಅನ್ನು ಅನುಮತಿಸಲು Bonjour ಸೇವೆಯನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>ಮೊದಲ ಹಾದಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>ವಿರುದ್ಧ ಮೂಲವು ಅಪ್ಲಿಕೇಶನ್ ಅನ್ನು ತೆರೆಯುತ್ತದೆ ಮತ್ತು ಅದೇ ನೆಟ್ವರ್ಕ್ ಗೆ ಸಂಪರ್ಕಿಕೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>ನಾಲ್ಕನೇ ಹಾದಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>ಐದನೇ ಹಾದಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>ಅನ್ನು ಕಳುಹಿಸಲು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>ಪೀರ್ ಉಪಕರಣಕ್ಕೆ ಸಂಪರ್ಕಿಸಲು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>ಪೀರ್ IP ಅನ್ನು ಹುಡುಕಲು ಬಳಸುವ ಬox ಗೆ ನಮ್ಮ ಪೀರ್ IP ಅನ್ನು ಬರೆಯಿರಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>ಕ್ಲಿಕ್ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>ಆಯ್ಕೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>ಅನ್ನು ಉಳಿಸಲು ಆಯ್ಕೆ ಮಾಡಿದ ಸ್ಥಳವು ಅನುಮತಿಸದು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>ಈ ಪಾಥ್ ಓನ್ಲಿ ರೀಡ್ ಆಗಿದೆ. ಅನ್ನು ಉಳಿಸಲು ಇನ್ನೊಂದು ಸ್ಥಳವನ್ನು ಆಯ್ಕೆ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>ವಿಷಯದ ಉಪಕರಣವು ಲಾಕ್ ಆಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>ನೀವು ಮೊಬೈಲ್ ಉಪಕರಣಗಳಲ್ಲಿ ಅದನ್ನು ಅನುಮತಿಸಬಹುದು</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>ಉಪಕರಣಗಳನ್ನು ಹುಡುಕುತ್ತಿದೆ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>ಸಿಸ್ಟಮ್ ಟ್ರೇಗೆ ಕನಿಷ್ಠಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>ನಿಭಾಗಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>ಯಾವುದೇ ಹೆಚ್ಚಿನ ಪ್ರಶ್ನೆಗಳಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>ವಾಪಸ್</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>ಆನುಮತಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>ದಯವಿಟ್ಟು ನಿಮ್ಮ ಪ್ರಕ್ರಿಯೆಯನ್ನು ಆಯ್ಕೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>ಪುನರ್ವಸತಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>ವಿಭಾಗಿಸಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>ಕಂಪ್ಯೂಟರ್</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>ಫೋನ್</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>ಅನುಮತಿಸಿದ ಉಪಕರಣದ ಆಯ್ಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>ಪ್ರೋಗ್ರಾಮ್ ಡೌನ್ಲೋಡ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>ವಿಂಡೋಸ್ ಪ್ರೋಗ್ರಾಮ್ ಡೌನ್ಲೋಡ್ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>ನೆಟ್ವರ್ಕ್‌ಗೆ ಸಂಪರ್ಕ ಸ್ಥಾಪಿಸಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. ಕ್ರಾಸ್-ಎಂಡ್ ಕೋಲಬರ್ಬರ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿ. ಯೂಒಎಸ್ ಮೇಲೆ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಅಪ್ಪ್ ಸ್ಟೋರ್ನಿಂದ ಡೌನ್ಲೋಡ್ ಮಾಡಬಹುದು, ನಿಮ್ಮ ವಿಂಡೋಸ್ ಬದಿಯಲ್ಲಿ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಡೌನ್ಲೋಡ್ ಮಾಡಲು: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>ಆಟೋಮೇಟಿಕ್ ಡಿವೈಸ್ ಅನ್ನು ಸೇರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>ಫೈಲ್ ಮ್ಯಾನೇಜರ್-ಸೆಟ್ಟಿಂಗ್ಸ್-ಫೈಲ್ ಡ್ರಾಪ್-ನಾನಿಗೆ ಫೈಲ್ ಡ್ರಾಪ್ ಮಾಡಲು ಈ ಬಳಕೆದಾರರನ್ನು ಅನುಮತಿಸಿ -&quot;ಒಟ್ಟಾರಂಭ ಲ್ಯಾಂನಲ್ಲಿರುವ ಎಲ್ಲರು&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>ಸೆಟ್ಟಿಂಗ್ಸ್-ಬೇಸಿಕ್ ಸೆಟ್ಟಿಂಗ್ಸ್-ಡಿಸ್ಕವರಿ ಮೋಡ್-&quot;ಒಟ್ಟಾರಂಭ ಲ್ಯಾಂನಲ್ಲಿರುವ ಎಲ್ಲರನ್ನು ಅನುಮತಿಸಿ&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. ಗುರಿಯಾದ ಡಿವೈಸ್ ಐಪಿ ಅನ್ನು ಮೇಲೆ ಸರ್ಚ್ ಬок್ಸ್ನಲ್ಲಿ ಪ್ರವೇಶಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>ಕೋಲಬರ್ಬರ ಡಿವೈಸ್ ಕಂಡು ಬರಲಾಗದು？</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. ಮೊಬೈಲ್ ಫೋನ್ ಕ್ರಾಸ್-ಎಂಡ್ ಕೋಲಬರ್ಬರ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಡೌನ್ಲೋಡ್ ಮಾಡಬೇಕು.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>ಆಟೋಮೇಟಿಕ್ ಡೌನ್ಲೋಡ್ ಮಾಡಲು ಹೋಗಿ&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. ಇನ್ಸ್ಟಾಲೇಶನ್ ನಂತರ, ಈ ಡಿವೈಸ್‌ಗೆ ಸಂಪರ್ಕ ಸ್ಥಾಪಿಸಲು ಕೋಡ್ ಸ್ಕಾನ್ ಮಾಡಿ.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. ಈ ಡಿವೈಸ್‌ನ್ನು ಸಂಪರ್ಕ ಸ್ಥಾಪಿಸಿದ ನಂತರ, ಮೊಬೈಲ್ ಅಂತ್ಯದ ಕ್ರಾಸ್-ಎಂಡ್ ಕೋಲಬರ್ಬರ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ತೆರೆದು ಇಟ್ಟುಕೊಳ್ಳಬೇಕು ಮತ್ತು ಈ ಡಿವೈಸ್‌ನೊಂದಿಗೆ ಒಟ್ಟಾರಂಭ ಲ್ಯಾಂನಲ್ಲಿರಬೇಕು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>ಬಳಕೆಯ ಸೂಚನೆಗಳು</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>ಯಾವುದೇ ಡಿವೈಸ್ ಕಂಡು ಬರಲಿಲ್ಲ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>ನಿಗ್ಗು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1”ಅನ್ನು ಸ್ಕ್ರೀನ್ ಕಾಸ್ಟಿಂಗ್ ಆರಂಭಿಸಲು ಅನ್ವಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>ವಾಪಸ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>ನಿರ್ಧರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1”ನಿಗ್ಗು ಸಂಪರ್ಕ ವಿಚ್ಛೇದಿಸಲಾಗಿದೆ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>ನೀವು &apos;%1&apos; ನಿಗ್ಗು ಮತ್ತು ಕೋಲಬರ್ಬರ ಕೆಲಸ ಮಾಡಲು ನಿಶ್ಚಯಿಸಿದ್ದೀರಾ?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>ನಿಗ್ಗು</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>ಉಳಿದ ಸಮಯ %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>ವಾಪಸ್ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>ಕೋಡ್ ಸ್ಕಾನ್ ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>ಕ್ರಾಸ್-ಎಂಡ್ ಕೋಲಬರ್ಬರ ಅಪ್ಲಿಕೇಶನ್ ಅನ್ನು ಕೋಡ್ ಸ್ಕಾನ್ ಮಾಡಲು ಬಳಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>ಮೊಬೈಲ್ ಫೋನ್‌ಗಳು ಮತ್ತು ಡಿವೈಸ್‌ಗಳು ಒಟ್ಟಾರಂಭ ಲ್ಯಾಂನಲ್ಲಿ ಸಂಪರ್ಕ ಸ್ಥಾಪಿಸಬೇಕು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>ಇಲ್ಲಿ ಕ್ಲಿಕ್ ಮಾಡಿ UOS ಆಸ್ಟಾನ್ ಅಪ್ಪ್ ಡೌನ್ಲೋಡ್ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>ಆಕ್</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>ನೋಡ್</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>ಊರ್ವಾರ್ಜನ್ ಸೇರಿದ್ದವು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>ಅನುಮತಿಸಲಾಗಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>ಪರದೆ ಬಲಭಾಗ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>ಪರದೆ ಎಡಭಾಗ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>ನೀವು ಸಹಯೋಗ ಮಾಡುತ್ತಿರುವವರು ಮಾತ್ರ ಅನುಮತಿಸಲ್ಪಡುತ್ತಾರೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>ಮುಖ್ಯ ಆಯ್ಕೆಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>ತೊಡಕು ಗುರುತಿಸುವ ಆಯ್ಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>ನಿಮ್ಮನ್ನು &quot;ನಿಯಮಿತ&quot; ಆವೃತ್ತಿಯ ಮೂಲಕ ಇತರ ಉಪಕರಣಗಳುಗಳು ತೊಡಕು ಮಾಡಬಹುದು ಮತ್ತು ನಿಮಗೆ ಸಂಪರ್ಕ ಹೊಂದಬಹುದು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>ಉಪಕರಣ ಹೆಸರು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>ಪರಿಧಿಯ ಹಂಚಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>ಪರಿಧಿಯ ಹಂಚಿಕೆಯನ್ನು ಅನುಮತಿಸುತ್ತದೆ, ಇದು ಸಹಯೋಗ ಮಾಡಲು ಸೇರಿದ ಉಪಕರಣಗಳು ಇತರ ಉಪಕರಣಗಳ ಮೂಲಕ ಈ ಉಪಕರಣವನ್ನು ನಿಯಂತ್ರಿಸಲು ಅನುಮತಿಸುತ್ತದೆ, ಕೀಬೋರ್ಡ್, ಮೌಸ್, ಟ್ರ್ಯಾಕ್ಪ್ಯಾಡ್ ಮುಂತಾದವು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>ಈ ಉಪಕರಣವು ಸಂಪರ್ಕದಲ್ಲಿರುವ ಬಾಗಿಲಿಗೆ ಸಂಪರ್ಕದಲ್ಲಿರುವ ಬಾಗಿಲಿನ ಪರದೆಯಿಂದ ಮೌಸ್ ಅನ್ನು ಸಂಪರ್ಕದಲ್ಲಿರುವ ಬಾಗಿಲಿನ ಸ್ಥಾನಕ್ಕೆ ಹೋಗುವಂತೆ ಮಾಡುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>ಸಂಪರ್ಕ ದಿಶೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>ನಿಮಗೆ ಫೈಲ್ಗಳನ್ನು ಕಳುಹಿಸಲು ಮುಖ್ಯವಾಗಿ ಈ ಬಳಕೆದಾರರನ್ನು ಅನುಮತಿಸುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>ಫೈಲ್ ಸೇವನೆ ಸ್ಥಳ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>ಕ್ಲಿಪ್ಬೋರ್ಡ್ ಹಂಚಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>ಸೇವೆ (ಸಂಪರ್ಕದಲ್ಲಿರುವ ಉಪಕರಣ) ಮೇಲೆ ಹಂಚಿಕೆಯನ್ನು ಅನುಮತಿಸಲಾದಾಗ, ಕ್ಲಿಪ್ಬೋರ್ಡ್ ಎರಡು ಕಂಪ್ಯೂಟರಿನ ಮೇಲೆ ಹಂಚಿಕೆಯಾಗುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>ಉಪಕರಣ ಹೆಸರು 1 ರಿಂದ 20 ಅಕ್ಷರಗಳನ್ನು ಹೊಂದಿರಬೇಕು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>ಉಪಕರಣ ಹೆಸರು 1 ರಿಂದ 63 ಅಕ್ಷರಗಳನ್ನು ಹೊಂದಿರಬೇಕು</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>ಅಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation> &quot;%1&quot; ಸಹಯೋಗ ಮಾಡಲು ಸಾಧ್ಯವಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>ನೀವು ಇನ್ನೊಂದು ಉಪಕರಣಕ್ಕೆ ಸಂಪರ್ಕ ಹೊಂದುತ್ತಿದ್ದೀರಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation> &quot;%1&quot; ಸಹಯೋಗ ಮಾಡಲು ಅರ್ಥಹರಿಸುತ್ತಿದ್ದೀರಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation> &quot;%1&quot; ಸಹಯೋಗ ಮುಖ್ಯವಾಗಿ ಮುಗಿದಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation> &quot;%1&quot; ಮೂಲಕ ಒಂದು ಅನುಮತಿಸಿದ ಸಹಯೋಗ ಅರ್ಥಹರಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>ಅಸ್ವಾಪ್ತ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>ಸ್ವಾಪ್ತ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>ಸಹಯೋಗ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation> &quot;%1&quot; ಸಂಪರ್ಕ ಹೊಂದಲು ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>ನಿಮ್ಮನ್ನು ಸಹಯೋಗಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>ಪ್ರಕ್ರಿಯೆ ಓಡಿಸಲು ವಿಫಲವಾಯಿತ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಸ್ಥಾಪನೆಯಾಗಿದೆ, &quot;%1&quot; ಸಹಯೋಗ ನಡೆಸುತ್ತಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; ನಿಮ್ಮ ಸಹಯೋಗ ಪ್ರಾರಂಭಿಸುವ ಅರ್ಥಹೀನತೆಯನ್ನು ನಿರಾಕರಿಸಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; ಇತರ ಯಂತ್ರಗಳೊಂದಿಗೆ ಸಂಪರ್ಕ ಹೊಂದುತ್ತಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>&quot;%1&quot; ನಿಮ್ಮನ್ನು ಸಂಪರ್ಕ ಪ್ರಾರಂಭಿಸಲು ಕೊಡುವ ಅರ್ಥಹೀನತೆಯನ್ನು ಸಮಯ ಸಾಧ್ಯವಿಲ್ಲದೆ ಅಡ್ಡಗೊಳಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>ಇತರ ಪಕ್ಷ ಗುರುತಿಸಲು ನಿಮಗೆಂದು ಸಮಯ ಸಾಧ್ಯವಿಲ್ಲದೆ ಅಡ್ಡಗೊಳಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>ಇತರ ಪಕ್ಷ ನೀವು ಕೊಡುವ ಸಂಪರ್ಕ ಅರ್ಥಹೀನತೆಯನ್ನು ರದ್ದುಪಡಿಸಿದೆ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>ಸಂಪರ್ಕ ವಿಫಲವಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಇಲ್ಲ, ಈ ಬಾರಿ ಅಂತರ್ಜಾಲ ಹರಿವು ವಿಫಲವಾಗಿದೆ. ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಮಾಡಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಇಲ್ಲ, ಈ ಬಾರಿ ಅಂತರ್ಜಾಲ ಹರಿವು ವಿಫಲವಾಗಿದೆ. ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಮಾಡಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಅಪವಾದ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>ನೆಟ್ವರ್ಕ್ &quot;%1&quot; ನ್ನು ತಪ್ಪಿಸಿ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>ಸಹಯೋಗ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕ ಸ್ಥಾಪನೆಯಾಗಿದೆ, &quot;%1&quot; ಸಹಯೋಗ ನಡೆಸುತ್ತಿದೆ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>&quot;%1&quot; ಸಂಪರ್ಕ ವಿಫಲವಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>ಅಂತರ್ಜಾಲ ಓದು/ರುಜುವಾದ ಅಪವಾದ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>ಇತರ ಪಕ್ಷ ಅಂತರ್ಜಾಲ ಹರಿವನ್ನು ರದ್ದುಪಡಿಸಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು ಯಶಸ್ವಿಯಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು ಇತಿಹಾಸವನ್ನು ನೋಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು ಕಳುಹಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>ಇತರ ಪಕ್ಷ ಗ್ರಹಿಸಲಿಲ್ಲ, ಅಂತರ್ಜಾಲ ಹರಿವು ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>ರದ್ದುಪಡಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>ಅಂತರ್ಜಾಲ ಗ್ರಹಿಸುತ್ತಿದೆ %1% | ಉಳಿದ ಸಮಯ %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು &quot;%1&quot; ಗೆ ಕಳುಹಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>ಅಂತರ್ಜಾಲ ಹರಿವು &quot;%1&quot; ಗೆ ಬರಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>ಅಸ್ಪೃಶ್ಯ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>ಸ್ವೀಕರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>ಮುಚ್ಚಿ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation> &quot;%1&quot; أرسل بعض الملفات إليك</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>مشاهدة</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>لقد ألغى الطرف الآخر طلب النقل ! </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>&gt;-
 مساحة تخزين غير كافية، فشل في تسليم الملف هذه المرة. من فضلك حظّر
 مساحة القرص وحاول مرة أخرى!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>&gt;-
 لم يتم الاتصال بالشبكة، فشل في تسليم الملف هذه المرة. من فضلك اتصل
 بالشبكة وحاول مرة أخرى!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>يتم الحساب</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>يتم رفض طلبك من قبل الطرف الآخر</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>نقل الملف</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>تم الانفصال</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>نقل الملف</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>انتظر التأكيد...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>من فضلك أدخل عنوان الجهاز / الاسم من Collaborator</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>جهاز قريب</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>إعادة المسح للجهاز</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>إرسال الملفات</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>نقل الملف</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>نقل الملف</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>إعدادات نقل الملف</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>كل شخص في نفس الشبكة المحلية</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>يسمح فقط لأولئك الذين يتعاونون</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>لا يسمح</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>يسمح للمستخدمين التاليين بإرسال الملفات إليّ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>مكان حفظ الملف</translation>
    </message>
</context>
</TS>